@@ -1,10 +1,11 @@
 import shutil
 from sqlalchemy.sql import text
+from FreeTAKServer.model.SQLAlchemy.Root import Base
 
 class TableController:
     # default constructor  def __init__(self):
     def __init__(self):
-        self.table = None
+        self.table: Base = object  # all inheriting methods MUST implement this variable
 
 
     def delete(self, session, query):
@@ -21,8 +22,12 @@ class TableController:
 
     def query(self, session, query, columns):
         # query needs to be applicable to datapackage object tuple(['DataPackage.'+x for x in columns])
-        output = session.query(*tuple([getattr(self.table, x) if x != '*' else self.table for x in columns])).filter(
-            text(query)).all()
+        if isinstance(query, str): 
+            output = session.query(*tuple([getattr(self.table, x) if x != '*' else self.table for x in columns])).filter(
+                text(query)).all()
+        elif isinstance(query, object):
+            output = session.query(*tuple([getattr(self.table, x) if x != '*' else self.table for x in columns])).filter(
+                query).all()
         return output
 
 
@@ -32,4 +37,4 @@ class TableController:
         for dp in DataPackages:
             for column, value in column_value.items():
                 setattr(dp, column, value)
-        session.commit()
\ No newline at end of file
+        session.commit()
