@@ -1,5 +1,6 @@
+from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.MimeTypeVariables import MimeTypeVariables as vars
-class MimeType:
+class MimeType(FTSProtocolObject):
     def __init__(self):
         self.INTAG = None
 
