@@ -19,4 +19,9 @@ class PrecisionlocationVariables:
     def UserUpdate(cls):
         cls.altsrc = None
         cls.geopointsrc = None
+        return cls
+
+    @classmethod
+    def SPISensor(cls):
+        cls.ALTSRC = "GPS"
         return cls
\ No newline at end of file
